@@ -677,11 +677,11 @@ def plot_node(
     len_ind = len(data_df.index)
     len_cols = len(data_df.columns)
     ynum = max(len_ind // 10, 1)
-    xnum = max(len_cols // 10, 1)
+    xnum = max(len_cols // 5, 1)
     yticks = [each for each in range(len_ind) if each % ynum == 0]
     xticks = [each for each in range(len_cols) if each % xnum == 0]
     plt.yticks(ticks=[y + .5 for y in yticks], labels=data_df.index[yticks])
-    plt.xticks(ticks=[x + .5 for x in xticks], labels=data_df.columns[xticks])
+    plt.xticks(ticks=[x + .5 for x in xticks], labels=data_df.columns[xticks], rotation=45, ha='right')
     plt.colorbar()
     # sns.set(rc={'figure.figsize': (10, 10)})
     # if data_df.max().max() > 50:
@@ -717,7 +717,7 @@ def plot_node(
         cell_text.append([f'{shorten(x)}' for x in row])
 
     plt.figure(linewidth=2,
-               figsize=(20, 9)
+               figsize=(10, 7)
                )
     plt.tight_layout()
     # Add a table at the bottom of the axes
